InfoServiceClient

Struct InfoServiceClient 

pub struct InfoServiceClient<T> { /* private fields */ }
Provide information about the hardware and/or software of a system.

Implementations

Source

impl InfoServiceClient<Channel>

pub async fn connect<D>(dst: D) -> Result<Self, Error>
where D: TryInto<Endpoint>, D::Error: Into<StdError>,

Attempt to create a new client by connecting to a given endpoint.

Source

impl<T> InfoServiceClient<T>
where T: GrpcService<BoxBody>, T::ResponseBody: Body + Send + Sync + 'static, T::Error: Into<StdError>, <T::ResponseBody as Body>::Error: Into<StdError> + Send,

pub fn new(inner: T) -> Self

pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> InfoServiceClient<InterceptedService<T, F>>
where F: Interceptor, T: Service<Request<BoxBody>, Response = Response<<T as GrpcService<BoxBody>>::ResponseBody>>, <T as Service<Request<BoxBody>>>::Error: Into<StdError> + Send + Sync,

pub fn send_gzip(self) -> Self

Compress requests with gzip.

This requires the server to support it otherwise it might respond with an error.

pub fn accept_gzip(self) -> Self

Enable decompressing responses with gzip.

pub async fn get_flight_information( &mut self, request: impl IntoRequest<GetFlightInformationRequest>, ) -> Result<Response<GetFlightInformationResponse>, Status>

Get flight information of the system.

pub async fn get_identification( &mut self, request: impl IntoRequest<GetIdentificationRequest>, ) -> Result<Response<GetIdentificationResponse>, Status>

Get the identification of the system.

pub async fn get_product( &mut self, request: impl IntoRequest<GetProductRequest>, ) -> Result<Response<GetProductResponse>, Status>

Get product information of the system.

pub async fn get_version( &mut self, request: impl IntoRequest<GetVersionRequest>, ) -> Result<Response<GetVersionResponse>, Status>

Get the version information of the system.

pub async fn get_speed_factor( &mut self, request: impl IntoRequest<GetSpeedFactorRequest>, ) -> Result<Response<GetSpeedFactorResponse>, Status>

Get the speed factor of a simulation (with lockstep a simulation can run faster or slower than realtime).