pub struct StatusText {
pub type: i32,
pub text: String,
}Expand description
StatusText information type.
Fields
type: i32Message type
text: StringMAVLink status message
Implementations
Sourceimpl StatusText
impl StatusText
Sourcepub fn type(&self) -> StatusTextType
pub fn type(&self) -> StatusTextType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: StatusTextType)
pub fn set_type(&mut self, value: StatusTextType)
Sets type to the provided enum value.