pub struct OffboardServiceServer<T: OffboardService> { /* private fields */ }Expand description
Control a drone with position, velocity, attitude or motor commands.
The module is called offboard because the commands can be sent from external sources as opposed to onboard control right inside the autopilot “board”.
Client code must specify a setpoint before starting offboard mode. Mavsdk automatically sends setpoints at 20Hz (PX4 Offboard mode requires that setpoints are minimally sent at 2Hz).
Implementations
Sourceimpl<T: OffboardService> OffboardServiceServer<T>
impl<T: OffboardService> OffboardServiceServer<T>
pub fn new(inner: T) -> Self
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> InterceptedService<Self, F>where
F: Interceptor,